@@ -81,6 +81,7 @@ get_labels <- function(model) {
 #' @param sentences [character] containing the sentences
 #' @param k will return the `k` most probable labels (default = 1)
 #' @param simplify when [TRUE] and `k` = 1, function return a (flat) [numeric] instead of a [list]
+#' @param unlock_empty_predictions [logical] to avoid crash when some predictions are not provided for some sentences because all their words have not been seen during training. This parameter should only be set to [TRUE] to debug.
 #' @param ... not used
 #' @return [list] containing for each sentence the probability to be associated with `k` labels.
 #' @examples
@@ -94,11 +95,19 @@ get_labels <- function(model) {
 #'
 #' @importFrom assertthat assert_that is.flag is.count
 #' @export
-predict.Rcpp_fastrtext <- function(object, sentences, k = 1, simplify = FALSE, ...) {
+predict.Rcpp_fastrtext <- function(object, sentences, k = 1, simplify = FALSE, unlock_empty_predictions = FALSE, ...) {
   assert_that(is.flag(simplify),
               is.count(k))
   if (simplify) assert_that(k == 1, msg = "simplify can only be used with k == 1")
+
   predictions <- object$predict(sentences, k)
+
+  # check empty predictions
+  if (!unlock_empty_predictions) {
+    assert_that(sum(lengths(predictions) == 0) == 0,
+                msg = "Some sentences have no predictions. It may be caused by the fact that all their words are have not been seen during the training.")
+  }
+
   if (simplify) {
     unlist(predictions)
   } else {
@@ -132,10 +141,6 @@ get_word_vectors <- function(model, words = get_dictionary(model)) {
 #'
 #' Use the same commands than the one to use for the command line.
 #'
-#' WARNING: for process using multi-threading,
-#' displaying information should be disabled (`-verbose 0`).
-#' This is due to incompatibility between `Rcpp::Rcout` and `pthread`.
-#'
 #' @param commands [character] of commands
 #' @examples
 #' \dontrun{
