@@ -14,6 +14,7 @@ train_tmp_file_txt <- tempfile()
 writeLines(text = train_to_write, con = train_tmp_file_txt)
 
 test_labels <- paste0("__label__", test_sentences[,"class.text"])
+test_labels_without_prefix <- test_sentences[,"class.text"]
 test_texts <- tolower(test_sentences[,"text"])
 test_to_write <- paste(test_labels, test_texts)
 
@@ -28,15 +29,18 @@ predictions <- predict(model, sentences = test_to_write)
 print(head(predictions, 5))
 
 # Compute accuracy
-mean(sapply(predictions, names) == test_labels)
+mean(names(unlist(predictions)) == test_labels_without_prefix)
 
 # because there is only one category by observation, hamming loss will be the same
-get_hamming_loss(as.list(test_labels), predictions)
+get_hamming_loss(as.list(test_labels_without_prefix), predictions)
 
 # test predictions
 predictions <- predict(model, sentences = test_to_write)
 print(head(predictions, 5))
 
+# you can get flat list of results when you are retrieving only one label per observation
+print(head(predict(model, sentences = test_to_write, simplify = TRUE)))
+
 # free memory
 unlink(train_tmp_file_txt)
 unlink(tmp_file_model)
